using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;
using System.Linq;
using System.Threading.Tasks;
using Microsoft.AspNetCore.Mvc;
using Microsoft.AspNetCore.Mvc.RazorPages;
using Microsoft.AspNetCore.Mvc.Rendering;
using DAL;
using Domain;
using Microsoft.CodeAnalysis.Options;
using Microsoft.EntityFrameworkCore;

namespace WebApp.Pages.Books
{
    public class CreateModel : PageModel
    {
        private readonly DAL.AppDbContext _context;

        public CreateModel(DAL.AppDbContext context)
        {
            _context = context;
        }

        public async Task<IActionResult> OnGet()
        {
            ViewData["PublisherId"] = new SelectList(_context.Publishers, "PublisherId", "PublisherName");
            AuthorSelectList = new SelectList(
                await _context.Authors.OrderBy(a => a.LastName).ThenBy(a => a.FirstName).ToListAsync(),
                nameof(Author.AuthorId), nameof(Author.FirstLastName));
            
            return Page();
        }

        [BindProperty]
        public Book Book { get; set; }
        
        [BindProperty]
        [Display(Name = "Publisher name", Prompt = "Please enter name for new publisher...")]
        public string? NewPublisherName { get; set; }

        [BindProperty]
        public IEnumerable<int> AuthorIds { get; set; }

        public SelectList AuthorSelectList { get; set; }
        
        // To protect from overposting attacks, please enable the specific properties you want to bind to, for
        // more details see https://aka.ms/RazorPagesCRUD.
        public async Task<IActionResult> OnPostAsync()
        {
            if (!ModelState.IsValid)
            {
                return Page();
            }

            if (Book.PublisherId == -1 && string.IsNullOrWhiteSpace(NewPublisherName))
            {
                ModelState.AddModelError(nameof(NewPublisherName), "Publisher name is required");
                return Page();
            }

            if (Book.PublisherId == -1 && !string.IsNullOrWhiteSpace(NewPublisherName))
            {
                var publisher = new Publisher() {PublisherName = NewPublisherName.Trim()};
                _context.Publishers.Add(publisher);
                Book.Publisher = publisher;
            }


            if (AuthorIds?.Count() > 0)
            {
                Book.BookAuthors = new List<BookAuthor>();
                foreach (var authorId in AuthorIds)
                {
                    Book.BookAuthors.Add(new BookAuthor(){Book = Book, AuthorId = authorId});
                }
            }



            _context.Books.Add(Book);
            await _context.SaveChangesAsync();

            return RedirectToPage("./Index");
        }
    }
}
