using System;
using System.Collections.Generic;
using System.Linq;
using System.Security.Policy;
using System.Threading.Tasks;
using Microsoft.AspNetCore.Mvc;
using Microsoft.AspNetCore.Mvc.RazorPages;
using Microsoft.EntityFrameworkCore;
using DAL;
using Domain;

namespace WebApp.Pages.Books
{
    public class IndexModel : PageModel
    {
        private readonly DAL.AppDbContext _context;
        

        public IndexModel(DAL.AppDbContext context)
        {
            _context = context;
        }

        public IList<Book> Book { get;set; }
        public string Search { get; set; } = "";

        public async Task OnGetAsync(string? search)
        {
            Search = search;

            if (!string.IsNullOrWhiteSpace(search))
            {
                search = search.ToLower().Trim();
                
                Book = await _context.Books
                    
                    .Include(b => b.Publisher)
                
                    .Include(b => b.BookAuthors)
                    .ThenInclude(b => b.Author)
                
                    .Include(b => b.Comments)
                    
                    .Where(b => 
                        b.BookTitle.ToLower().Contains(search) || 
                        b.Publisher.PublisherName.ToLower().Contains(search) ||
                        b.Comments.Any(c => c.CommentText.ToLower().Contains(search)) ||
                        b.BookAuthors.Any(d => 
                            d.Author.FirstName.ToLower().Contains(search) || 
                            d.Author.LastName.ToLower().Contains(search))
                        )
                    .ToListAsync();

            }
            else
            {
                Book = await _context.Books
                    
                    .Include(b => b.Publisher)
                
                    .Include(b => b.BookAuthors)
                    .ThenInclude(b => b.Author)
                
                    .Include(b => b.Comments)
                    .ToListAsync();
            }

        }
    }
}
